@@ -13,13 +13,14 @@ from pulpcore.client.pulp_ansible.api.content_roles_api import ContentRolesApi
 from pulpcore.client.pulp_ansible.api.distributions_ansible_api import DistributionsAnsibleApi
 from pulpcore.client.pulp_ansible.api.galaxy_detail_api import GalaxyDetailApi
 from pulpcore.client.pulp_ansible.api.pulp_ansible_api_api import PulpAnsibleApiApi
-from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_collections_api import PulpAnsibleGalaxyApiCollectionsApi
-from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v2_versions_api import PulpAnsibleGalaxyApiV2VersionsApi
-from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v3_all_api import PulpAnsibleGalaxyApiV3AllApi
-from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v3_collections_api import PulpAnsibleGalaxyApiV3CollectionsApi
-from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v3_collections_docs_blob_api import PulpAnsibleGalaxyApiV3CollectionsDocsBlobApi
-from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_api_v3_versions_api import PulpAnsibleGalaxyApiV3VersionsApi
-from pulpcore.client.pulp_ansible.api.pulp_ansible_galaxy_v3_api import PulpAnsibleGalaxyV3Api
+from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v2_collections_versions_api import PulpAnsibleApiV2CollectionsVersionsApi
+from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_api import PulpAnsibleApiV3Api
+from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collection_versions_all_api import PulpAnsibleApiV3CollectionVersionsAllApi
+from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collections_api import PulpAnsibleApiV3CollectionsApi
+from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collections_all_api import PulpAnsibleApiV3CollectionsAllApi
+from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collections_versions_api import PulpAnsibleApiV3CollectionsVersionsApi
+from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collections_versions_docs_blob_api import PulpAnsibleApiV3CollectionsVersionsDocsBlobApi
+from pulpcore.client.pulp_ansible.api.pulp_ansible_artifacts_collections_v3_api import PulpAnsibleArtifactsCollectionsV3Api
 from pulpcore.client.pulp_ansible.api.pulp_ansible_tags_api import PulpAnsibleTagsApi
 from pulpcore.client.pulp_ansible.api.remotes_collection_api import RemotesCollectionApi
 from pulpcore.client.pulp_ansible.api.remotes_role_api import RemotesRoleApi
